==> liquidwar6-0.0.1beta.tar.gz: liquidwar6-0.0.1beta/src/lib/gfx/mod-gl/gl-hud/gl-floating/gl-floating-display.c <==
/*
Liquid War 6 is a unique multiplayer wargame.
Copyright (C)  2005, 2006  Christian Mauduit <ufoot@ufoot.org>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
Contact author        : ufoot@ufoot.org
*/

#include <stdio.h>
#include <stdlib.h>

#include <GL/glu.h>

#include "config.h"
#include "../../mod-gl.h"
#include "gl-floating-internal.h"

static void
hud_display (MOD_GL_UTILS_CONTEXT * utils_context,
	     _MOD_GL_HUD_FLOATING_CONTEXT * floating_context)
{
  // todo
}


void
_mod_gl_hud_floating_display (MOD_GL_UTILS_CONTEXT * utils_context,
			      _MOD_GL_HUD_FLOATING_CONTEXT * floating_context,
			      LW6KER_GAME_STATE * game_state)
{
  hud_display (utils_context, floating_context);
}

void
mod_gl_hud_floating_display (MOD_GL_UTILS_CONTEXT * utils_context,
			     void *hud_context,
			     LW6KER_GAME_STATE * game_state,
			     LW6GFX_HUD_STEP step)
{
  if (step == LW6GFX_HUD_STEP_FG)
    {
      _mod_gl_hud_floating_display (utils_context,
				    (_MOD_GL_HUD_FLOATING_CONTEXT *)
				    hud_context, game_state);
    }
}

void
_mod_gl_hud_floating_display_preview (MOD_GL_UTILS_CONTEXT * utils_context,
				      _MOD_GL_HUD_FLOATING_CONTEXT *
				      floating_context)
{
  hud_display (utils_context, floating_context);
}


void
mod_gl_hud_floating_display_preview (MOD_GL_UTILS_CONTEXT * utils_context,
				     void *hud_context, LW6GFX_HUD_STEP step)
{
  if (step == LW6GFX_HUD_STEP_FG)
    {
      _mod_gl_hud_floating_display_preview (utils_context,
					    (_MOD_GL_HUD_FLOATING_CONTEXT *)
					    hud_context);
    }
}

==> liquidwar6-0.0.2beta.tar.gz: liquidwar6-0.0.2beta/src/lib/gfx/mod-gl/gl-hud/gl-floating/gl-floating-display.c <==
/*
Liquid War 6 is a unique multiplayer wargame.
Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.


Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
Contact author        : ufoot@ufoot.org
*/

#include <stdio.h>
#include <stdlib.h>

#include <GL/glu.h>

#include "config.h"
#include "../../mod-gl.h"
#include "gl-floating-internal.h"

static void
hud_display (MOD_GL_UTILS_CONTEXT * utils_context,
	     _MOD_GL_HUD_FLOATING_CONTEXT * floating_context)
{
  // todo
}


void
_mod_gl_hud_floating_display (MOD_GL_UTILS_CONTEXT * utils_context,
			      _MOD_GL_HUD_FLOATING_CONTEXT * floating_context,
			      LW6KER_GAME_STATE * game_state)
{
  hud_display (utils_context, floating_context);
}

void
mod_gl_hud_floating_display (MOD_GL_UTILS_CONTEXT * utils_context,
			     void *hud_context,
			     LW6KER_GAME_STATE * game_state,
			     LW6GFX_HUD_STEP step)
{
  if (step == LW6GFX_HUD_STEP_FG)
    {
      _mod_gl_hud_floating_display (utils_context,
				    (_MOD_GL_HUD_FLOATING_CONTEXT *)
				    hud_context, game_state);
    }
}

void
_mod_gl_hud_floating_display_preview (MOD_GL_UTILS_CONTEXT * utils_context,
				      _MOD_GL_HUD_FLOATING_CONTEXT *
				      floating_context)
{
  hud_display (utils_context, floating_context);
}


void
mod_gl_hud_floating_display_preview (MOD_GL_UTILS_CONTEXT * utils_context,
				     void *hud_context, LW6GFX_HUD_STEP step)
{
  if (step == LW6GFX_HUD_STEP_FG)
    {
      _mod_gl_hud_floating_display_preview (utils_context,
					    (_MOD_GL_HUD_FLOATING_CONTEXT *)
					    hud_context);
    }
}
